<?php

if ( ! function_exists( 'blocksy_post_meta' ) ) {
	/**
	 * array(
	 *   'author' => 'yes' | 'no' | true | false,
	 *   'comments' => 'yes' | 'no' | true | false,
	 *   'post_date' => 'yes' | 'no' | true | false,
	 *   'categories' => 'yes' | 'no' | true | false,
	 * )
	 */
	function blocksy_post_meta( $post_meta_descriptor = [], $args = [] ) {
		$post_meta_descriptor = array_merge(
			[
				'author' => false,
				'comments' => false,
				'post_date' => false,
				'categories' => false,
				'author_avatar' => false,
				'tags' => false,
			],
			$post_meta_descriptor
		);

		$args = wp_parse_args(
			$args,
			[
				'class' => '',
				'avatar_size' => '35px',
				'labels' => true,
				'category_style' => 'simple',
				'plain' => false
			]
		);

		if ( ! empty( $args['class'] ) ) {
			$args['class'] = ' ' . $args['class'];
		}

		global $post;

		if ( get_post_type( $post ) === 'page' ) {
			$post_meta_descriptor['comments'] = false;
			$post_meta_descriptor['categories'] = false;
			$post_meta_descriptor['tags'] = false;
		}

		if ( ! in_array( true, array_values( $post_meta_descriptor ), true ) ) {
			return '';
		}

		// Author ID
		global $post;
		$user_id = $post->post_author;

		$avatar = '';

		if ( $post_meta_descriptor['author_avatar'] ) {
			$avatar = ' has-avatar';
		}

		ob_start();

		?>

			<?php if ( $post_meta_descriptor['author'] && get_the_author() ) { ?>
				<li class="ct-meta-author" <?php blocksy_schema_org_definitions_e('author_name') ?>>
					<span class="ct-meta-label">
						<?php echo esc_html(__( 'By', 'blocksy' )); ?>
					</span>

					<span class="ct-meta-element" <?php blocksy_schema_org_definitions_e('author_link') ?>>
						<?php echo wp_kses_post(get_the_author_posts_link()); ?>
					</span>
				</li>
			<?php } ?>

			<?php if ( $post_meta_descriptor['post_date'] ) { ?>
				<li
					class="ct-meta-date"
					<?php blocksy_schema_org_definitions_e('publish_date') ?>>

					<span class="ct-meta-label">
						<?php echo esc_html(__( 'On', 'blocksy' )); ?>
					</span>

					<span class="ct-meta-element">
						<?php echo esc_html(get_the_date( 'M j, Y' )); ?>
					</span>
				</li>
			<?php } ?>

			<?php if ( $post_meta_descriptor['comments'] && get_comments_number() > 0 ) { ?>
				<li class="ct-meta-comments">
					<a class="ct-meta-element" href="<?php echo esc_attr(get_permalink()); ?>#ct-comments">
						<?php if ( get_post_type() === 'product' ) { ?>
							<?php echo esc_html(get_comments_number_text( '', '1 Review', '% Reviews' )); ?>
						<?php } else { ?>
							<?php echo esc_html(get_comments_number_text( '', '1 Comment', '% Comments' )); ?>
						<?php } ?>
					</a>
				</li>
			<?php } ?>

			<?php
			if ( $post_meta_descriptor['categories'] && blocksy_get_categories_list() ) {
				if (!$args['plain']) {
					echo '<li class="ct-meta-categories" data-type="' . esc_attr($args['category_style']) . '">';
					echo '<span class="ct-meta-label">';
					echo esc_html(__( 'In ', 'blocksy' ));
					echo '</span>';

					echo '<span class="ct-meta-element">';
					echo wp_kses_post(blocksy_get_categories_list( ' </span><span class="ct-meta-element">' ));
					echo '</span>';
					echo '</li>';
				} else {
					echo '<li>';
					echo wp_kses_post(blocksy_get_categories_list( '</li><li>' ));
					echo '</li>';
				}

			}

			if ( $post_meta_descriptor['tags'] && blocksy_get_categories_list( '', false ) ) {
				echo '<li>';
				echo wp_kses_post(blocksy_get_categories_list( '</li><li>', false ));
				echo '</li>';
			}

			?>
		<?php

		$to_return = ob_get_contents();
		ob_end_clean();

		if ( empty( trim( $to_return ) ) ) {
			return '';
		}

		$label_output = '';

		if ($args['labels'] && !$args['plain']) {
			$label_output = 'data-label';
		}

		$class_output = '';

		if ($args['plain']) {
			$class_output = 'class="product-categories"';
		}

		ob_start();

		?>

		<?php if (!$args['plain']) { ?>
		<div class="entry-meta<?php echo esc_attr($avatar); ?><?php echo esc_attr($args['class']); ?>" <?php echo wp_kses_post($label_output) ?>>
		<?php } ?>

			<?php if ( $post_meta_descriptor['author'] && get_the_author() ) { ?>
				<?php if ( $post_meta_descriptor['author_avatar'] ) { ?>
					<a href="<?php echo esc_attr(get_author_posts_url( get_the_author_meta( 'ID' ) )); ?>" class="avatar-container">
						<?php echo wp_kses_post(get_avatar( get_the_author_meta( 'ID' ), $args['avatar_size'] )); ?>
					</a>
				<?php } ?>
			<?php } ?>

			<ul <?php echo wp_kses_post($class_output) ?>>
				<?php 
					/**
					 * Note to code reviewers: This line doesn't need to be escaped.
					 * Var $to_return used here has the value escaped properly.
					 */
					echo $to_return;
				?>
			</ul>
		<?php if (!$args['plain']) { ?>
		</div>
		<?php } ?>

		<?php

		return ob_get_clean();
	}
}

function blocksy_get_categories_list( $between = '', $is_category = true ) {
	global $post;

	$category = $is_category ? 'category' : 'post_tag';

	if ( get_post_type( $post ) === 'fw-portfolio' ) {
		$category = 'fw-portfolio-category';
	}

	if ( get_post_type( $post ) === 'product' ) {
		$category = $is_category ? 'product_cat' : 'product_tag';
	}

	return get_the_term_list( $post, $category, '', $between );
}

